@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-#
 # the __all__ is generated
 __all__ = []
 
@@ -21,10 +20,10 @@ from .macd import *
 from .macd import __all__ as _macd_all
 __all__ += _macd_all
 
-# import all from submodule zen
-from .zen import *
-from .zen import __all__ as _zen_all
-__all__ += _zen_all
+# import all from submodule z
+from .z import *
+from .z import __all__ as _z_all
+__all__ += _z_all
 
 # import all from submodule technical_factor
 from .technical_factor import *
@@ -39,4 +38,9 @@ __all__ += _fundamental_all
 # import all from submodule target_selector
 from .target_selector import *
 from .target_selector import __all__ as _target_selector_all
-__all__ += _target_selector_all
\ No newline at end of file
+__all__ += _target_selector_all
+
+# import all from submodule shape
+from .shape import *
+from .shape import __all__ as _shape_all
+__all__ += _shape_all
\ No newline at end of file
