@@ -43,5 +43,5 @@ if __name__ == '__main__':
     gen_exports('utils')
     # gen_exports('trader')
     # gen_exports('autocode')
-    # gen_exports('factors')
+    gen_exports('factors')
     # gen_kdata_schemas()
