@@ -14,4 +14,9 @@ __all__ += _em_stockus_meta_recorder_all
 # import all from submodule em_stockhk_meta_recorder
 from .em_stockhk_meta_recorder import *
 from .em_stockhk_meta_recorder import __all__ as _em_stockhk_meta_recorder_all
-__all__ += _em_stockhk_meta_recorder_all
\ No newline at end of file
+__all__ += _em_stockhk_meta_recorder_all
+
+# import all from submodule em_stock_meta_recorder
+from .em_stock_meta_recorder import *
+from .em_stock_meta_recorder import __all__ as _em_stock_meta_recorder_all
+__all__ += _em_stock_meta_recorder_all
\ No newline at end of file
