@@ -53,6 +53,24 @@ class BaseEMStockKdataRecorder(FixedCycleDataRecorder):
         else:
             self.logger.info(f'no kdata for {entity.id}')
 
+    def on_finish_entity(self, entity):
+        # fill timestamp
+        if not entity.timestamp or not entity.list_date:
+            # get the first
+            kdatas = self.data_schema.query_data(provider=self.provider, entity_id=entity.id,
+                                                 order=self.data_schema.timestamp.asc(), limit=1, return_type='domain')
+            if kdatas:
+                timestamp = kdatas[0].timestamp
+
+                self.logger.info(f'fill {entity.name} list_date as {timestamp}')
+
+                if not entity.timestamp:
+                    entity.timestamp = timestamp
+                if not entity.list_date:
+                    entity.list_date = timestamp
+                self.entity_session.add(entity)
+                self.entity_session.commit()
+
 
 class EMStockKdataRecorder(BaseEMStockKdataRecorder):
     entity_schema = Stock
@@ -86,7 +104,7 @@ class EMBlockKdataRecorder(BaseEMStockKdataRecorder):
 
 
 if __name__ == '__main__':
-    recorder = EMIndexKdataRecorder(level=IntervalLevel.LEVEL_1DAY, codes=['000300'])
+    recorder = EMBlockKdataRecorder(level=IntervalLevel.LEVEL_1DAY, codes=['000300'])
     recorder.run()
 # the __all__ is generated
 __all__ = ['BaseEMStockKdataRecorder', 'EMStockKdataRecorder', 'EMStockusKdataRecorder', 'EMStockhkKdataRecorder',
