@@ -27,3 +27,5 @@ class InvalidOrderError(TraderError):
 class WrongKdataError(TraderError):
     def __init__(self, message="wrong kdata"):
         self.message = message
+# the __all__ is generated
+__all__ = ['TraderError', 'InvalidOrderParamError', 'NotEnoughMoneyError', 'NotEnoughPositionError', 'InvalidOrderError', 'WrongKdataError']
\ No newline at end of file
